@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2023-2024, by Samuel Williams.
+# Copyright, 2023-2025, by Samuel Williams.
 
 source "https://rubygems.org"
 
@@ -13,6 +13,8 @@ group :maintenance, optional: true do
 	gem "bake-modernize"
 	gem "bake-gem"
 	
+	gem "agent-context"
+	
 	gem "utopia-project" #, path: "../utopia-project"
 end
 
@@ -20,7 +22,10 @@ group :test do
 	gem "sus"
 	gem "covered"
 	gem "decode"
+	
 	gem "rubocop"
+	gem "rubocop-md"
+	gem "rubocop-socketry"
 	
 	gem "bake-test"
 	gem "bake-test-external"
